@@ -24,47 +24,47 @@ class _DataInterface(metaclass=Singleton):
 
         Args:
             config: Configuration object. with the following attributes:
-                api.username (str): API username.
-                api.password (str): API password.
-                api.admin_username (str): API admin username.
-                api.admin_password (str): API admin password.
-                api.url (str): API url.
-                influxdb.username (str): InfluxDB username.
-                influxdb.password (str): InfluxDB password.
-                influxdb.host (str): InfluxDB host.
-                influxdb.port (int): InfluxDB port.
-                mysql.username (str): MySQL username.
-                mysql.password (str): MySQL password.
-                mysql.host (str): MySQL host.
-                mysql.port (int): MYSQL port.
-                mysql.database_name (str): MySQL database name.
+                api_username (str): API username.
+                api_password (str): API password.
+                api_admin_username (str): API admin username.
+                api_admin_password (str): API admin password.
+                api_url (str): API url.
+                influxdb_username (str): InfluxDB username.
+                influxdb_password (str): InfluxDB password.
+                influxdb_host (str): InfluxDB host.
+                influxdb_port (int): InfluxDB port.
+                mysql_username (str): MySQL username.
+                mysql_password (str): MySQL password.
+                mysql_host (str): MySQL host.
+                mysql_port (int): MYSQL port.
+                mysql_database_name (str): MySQL database name.
                 proxies Union[dict[str, str], None]: Proxies.
         """
 
         self.logger = logging.get_logger(self.__class__.__name__)
 
         self.ktp_api = KtpApi(
-            username=config.api.username,
-            password=config.api.password,
-            admin_username=config.api.admin_username,
-            admin_password=config.api.admin_password,
-            url=config.api.url,
+            username=config.api_username,
+            password=config.api_password,
+            admin_username=config.api_admin_username,
+            admin_password=config.api_admin_password,
+            url=config.api_url,
             proxies=config.proxies,
         )
 
         self.influx_client = self._create_influx_client(
-            username=config.influxdb.username,
-            password=config.influxdb.password,
-            host=config.influxdb.host,
-            port=config.influxdb.port,
+            username=config.influxdb_username,
+            password=config.influxdb_password,
+            host=config.influxdb_host,
+            port=config.influxdb_port,
         )
 
         self.mysql_engine = self._create_mysql_engine(
-            username=config.mysql.username,
-            password=config.mysql.password,
-            host=config.mysql.host,
-            port=config.mysql.port,
-            db=config.mysql.database_name,
+            username=config.mysql_username,
+            password=config.mysql_password,
+            host=config.mysql_host,
+            port=config.mysql_port,
+            db=config.mysql_database_name,
         )
 
         # Set geopy proxies
