@@ -1,4 +1,4 @@
-# SPDX-FileCopyrightText: 2021 2017-2021 Contributors to the OpenSTF project <korte.termijn.prognoses@alliander.com>
+# SPDX-FileCopyrightText: 2017-2022 Contributors to the OpenSTEF project <korte.termijn.prognoses@alliander.com>
 #
 # SPDX-License-Identifier: MPL-2.0
 
@@ -238,4 +238,4 @@ class ModelInput:
             result.slope_center = float(result.slope_center)
             result.steepness = float(result.steepness)
 
-            return result.to_dict(orient="records")[0]
+            return result.to_dict("records")[0]
